@@ -5,7 +5,9 @@ use GRID::Machine::Group;
 use List::Util qw(sum);
 use Time::HiRes qw(time gettimeofday tv_interval);
 
-my @MACHINE_NAMES = split /\s+/, $ENV{MACHINES};
+my @MACHINE_NAMES = split /\s+/, ($ENV{MACHINES} || '');
+@MACHINE_NAMES = ('', '') unless @MACHINE_NAMES;
+
 my @m = map { GRID::Machine->new(host => $_, wait => 5, survive => 1) } @MACHINE_NAMES;
 
 my $c = GRID::Machine::Group->new(cluster => [ @m ]);
